@@ -57,6 +57,19 @@ class TestTmpBind(object):
             } == tmp_log._context._dict == log._context._dict
         assert {'y': 23} == log._context._dict
 
+    def test_bind_exc(self, log):
+        """
+        tmp_bind cleans up properly on exceptions.
+        """
+        log = log.bind(y=23)
+        with pytest.raises(ValueError):
+            with tmp_bind(log, x=42, y='foo') as tmp_log:
+                assert {
+                           'y': 'foo', 'x': 42
+                       } == tmp_log._context._dict == log._context._dict
+                raise ValueError
+        assert {'y': 23} == log._context._dict
+
 
 class TestAsImmutable(object):
     def test_does_not_affect_global(self, log):
@@ -189,14 +202,24 @@ class TestThreadLocalDict(object):
         assert 42 == d._dict["delattr"]
         del d.__class__._tl.dict_
 
+    def test_delattr_missing(self, D):
+        """
+        __delattr__ on an inexisting attribute raises AttributeError.
+        """
+        d = D()
+        with pytest.raises(AttributeError) as e:
+            d._tl.__delattr__("does_not_exist")
+        assert "does_not_exist" == e.value.args[0]
+
     def test_del(self, D):
         """
         ___del__ is proxied to the wrapped class.
         """
         d = D()
-        d['del'] = 13
-        del d['del']
-        assert 'del' not in d._dict
+        d["del"] = 13
+        assert 13 == d._dict["del"]
+        del d["del"]
+        assert "del" not in d._dict
 
     def test_new_class(self, D):
         """
